@@ -4,6 +4,7 @@
  *
  * Copyright (C) 2011 Red Hat, Inc.
  *               2012 Stefano Karapetsas
+ * Copyright (C) 2012-2021 The MATE developers
  *
  * Caja is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -49,7 +50,7 @@ get_keyfile_path (void)
     retval = g_build_filename (xdg_dir, "desktop-metadata", NULL);
 
     g_free (xdg_dir);
-    
+
     return retval;
 }
 
@@ -176,7 +177,7 @@ caja_desktop_set_metadata_string (CajaFile *file,
 
     if (caja_desktop_update_metadata_from_keyfile (file, name)) {
         caja_file_changed (file);
-    }    
+    }
 }
 
 #define STRV_TERMINATOR "@x-caja-desktop-metadata-term@"
@@ -235,12 +236,11 @@ caja_desktop_update_metadata_from_keyfile (CajaFile *file,
 {
     gchar **keys, **values;
     const gchar *actual_values[2];
-    const gchar *key, *value;
-    gchar *gio_key;
+    const gchar *value;
     gsize length, values_length;
     GKeyFile *keyfile;
     GFileInfo *info;
-    gint idx;
+    gsize idx;
     gboolean res;
 
     keyfile = get_keyfile ();
@@ -257,6 +257,9 @@ caja_desktop_update_metadata_from_keyfile (CajaFile *file,
     info = g_file_info_new ();
 
     for (idx = 0; idx < length; idx++) {
+        const gchar *key;
+        gchar *gio_key;
+
         key = keys[idx];
         values = g_key_file_get_string_list (keyfile,
                              name,
