@@ -92,7 +92,6 @@ caja_drag_finalize (CajaDragInfo *drag_info)
     g_free (drag_info);
 }
 
-
 /* Functions to deal with CajaDragSelectionItems.  */
 
 CajaDragSelectionItem *
@@ -205,7 +204,7 @@ caja_drag_build_selection_list (GtkSelectionData *data)
         if (*p == '\n' || *p == '\0')
         {
             result = g_list_prepend (result, item);
-            if (p == 0)
+            if (*p != '\n')
             {
                 g_warning ("Invalid x-special/mate-icon-list data received: "
                            "missing newline character.");
@@ -609,7 +608,7 @@ add_one_mate_icon (const char *uri, int x, int y, int w, int h,
 
     result = (GString *) data;
 
-    g_string_append_printf (result, "%s\r%d:%d:%hu:%hu\r\n",
+    g_string_append_printf (result, "%s\r%d:%d:%d:%d\r\n",
                             uri, x, y, w, h);
 }
 
@@ -929,7 +928,6 @@ caja_drag_autoscroll_in_scroll_region (GtkWidget *widget)
     return x_scroll_delta != 0 || y_scroll_delta != 0;
 }
 
-
 void
 caja_drag_autoscroll_calculate_delta (GtkWidget *widget, float *x_scroll_delta, float *y_scroll_delta)
 {
@@ -1017,8 +1015,6 @@ caja_drag_autoscroll_calculate_delta (GtkWidget *widget, float *x_scroll_delta,
 
 }
 
-
-
 void
 caja_drag_autoscroll_start (CajaDragInfo *drag_info,
                             GtkWidget        *widget,
@@ -1240,7 +1236,6 @@ slot_proxy_drag_drop (GtkWidget          *widget,
     return TRUE;
 }
 
-
 static void
 slot_proxy_handle_drop (GtkWidget                *widget,
                         GdkDragContext           *context,
@@ -1318,7 +1313,6 @@ slot_proxy_handle_drop (GtkWidget                *widget,
                     gdk_drag_context_get_selected_action (context));
         }
 
-
         gtk_drag_finish (context, TRUE, FALSE, time);
     }
     else
@@ -1429,4 +1423,3 @@ caja_drag_slot_proxy_init (GtkWidget *widget,
                       drag_info);
 }
 
-
