@@ -42,11 +42,10 @@
 #define CAJA_ICON_CONTAINER_GET_CLASS(obj) \
   (G_TYPE_INSTANCE_GET_CLASS ((obj), CAJA_TYPE_ICON_CONTAINER, CajaIconContainerClass))
 
-
 #define CAJA_ICON_CONTAINER_ICON_DATA(pointer) \
 	((CajaIconData *) (pointer))
 
-typedef struct CajaIconData CajaIconData;
+typedef void CajaIconData;
 
 typedef void (* CajaIconCallback) (CajaIconData *icon_data,
                                    gpointer callback_data);
@@ -245,7 +244,6 @@ typedef struct
 GType             caja_icon_container_get_type                      (void);
 GtkWidget *       caja_icon_container_new                           (void);
 
-
 /* adding, removing, and managing icons */
 void              caja_icon_container_clear                         (CajaIconContainer  *view);
 gboolean          caja_icon_container_add                           (CajaIconContainer  *view,
@@ -301,7 +299,6 @@ void              caja_icon_container_set_highlighted_for_clipboard (CajaIconCon
 void              caja_icon_container_unselect_all                  (CajaIconContainer  *view);
 void              caja_icon_container_select_all                    (CajaIconContainer  *view);
 
-
 /* operations on the selection */
 GList     *       caja_icon_container_get_selection                 (CajaIconContainer  *view);
 void			  caja_icon_container_invert_selection				(CajaIconContainer  *view);
@@ -361,7 +358,6 @@ void              caja_icon_container_set_store_layout_timestamps   (CajaIconCon
 void              caja_icon_container_widget_to_file_operation_position (CajaIconContainer *container,
         GdkPoint              *position);
 
-
 #define CANVAS_WIDTH(container,allocation) ((allocation.width	  \
 				- container->details->left_margin \
 				- container->details->right_margin) \
