@@ -26,19 +26,20 @@
 */
 
 #include <config.h>
-#include "caja-mime-application-chooser.h"
-
-#include "caja-open-with-dialog.h"
-#include "caja-signaller.h"
-#include "caja-file.h"
-#include <eel/eel-stock-dialogs.h>
-
 #include <string.h>
+
 #include <glib/gi18n-lib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 
+#include <eel/eel-stock-dialogs.h>
+
+#include "caja-mime-application-chooser.h"
+#include "caja-open-with-dialog.h"
+#include "caja-signaller.h"
+#include "caja-file.h"
+
 struct _CajaMimeApplicationChooserDetails
 {
     char *uri;
@@ -51,7 +52,6 @@ struct _CajaMimeApplicationChooserDetails
     guint refresh_timeout;
 
     GtkWidget *label;
-    GtkWidget *entry;
     GtkWidget *treeview;
     GtkWidget *remove_button;
 
@@ -93,7 +93,6 @@ caja_mime_application_chooser_finalize (GObject *object)
                                           G_CALLBACK (mime_type_data_changed_cb),
                                           chooser);
 
-
     g_free (chooser->details->uri);
     g_free (chooser->details->content_type);
     g_free (chooser->details->extension);
@@ -133,7 +132,6 @@ default_toggled_cb (GtkCellRendererToggle *renderer,
         gboolean is_default;
         gboolean success;
         GAppInfo *info;
-        char *message;
 
         gtk_tree_model_get (GTK_TREE_MODEL (chooser->details->model),
                             &iter,
@@ -159,6 +157,8 @@ default_toggled_cb (GtkCellRendererToggle *renderer,
 
             if (!success)
             {
+                char *message;
+
                 message = g_strdup_printf (_("Could not set application as the default: %s"), error->message);
                 eel_show_error_dialog (_("Could not set as default application"),
                                        message,
@@ -417,7 +417,9 @@ caja_mime_application_chooser_init (CajaMimeApplicationChooser *chooser)
     gtk_box_pack_start (GTK_BOX (chooser), box, FALSE, FALSE, 6);
     gtk_widget_show (box);
 
-    button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+    button = gtk_button_new_with_mnemonic (_("_Add"));
+    gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_icon_name ("list-add", GTK_ICON_SIZE_BUTTON));
+
     g_signal_connect (button, "clicked",
                       G_CALLBACK (add_clicked_cb),
                       chooser);
@@ -425,7 +427,9 @@ caja_mime_application_chooser_init (CajaMimeApplicationChooser *chooser)
     gtk_widget_show (button);
     gtk_container_add (GTK_CONTAINER (box), button);
 
-    button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+    button = gtk_button_new_with_mnemonic (_("_Remove"));
+    gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_icon_name ("list-remove", GTK_ICON_SIZE_BUTTON));
+
     g_signal_connect (button, "clicked",
                       G_CALLBACK (remove_clicked_cb),
                       chooser);
