@@ -1,12 +1,12 @@
 
-
 #ifndef __CAJA_RECENT_H__
 #define __CAJA_RECENT_H__
 
 #include <gtk/gtk.h>
-#include <libcaja-private/caja-file.h>
 #include <gio/gio.h>
 
+#include "caja-file.h"
+
 void caja_recent_add_file (CajaFile *file,
                            GAppInfo *application);
 
