@@ -21,19 +21,21 @@
 */
 
 #include <config.h>
+#include <string.h>
+
+#include <gtk/gtk.h>
+#include <gio/gio.h>
+#include <sys/time.h>
+
+#include <eel/eel-glib-extensions.h>
+
 #include "caja-search-directory.h"
 #include "caja-search-directory-file.h"
-
 #include "caja-directory-private.h"
 #include "caja-file.h"
 #include "caja-file-private.h"
 #include "caja-file-utilities.h"
 #include "caja-search-engine.h"
-#include <eel/eel-glib-extensions.h>
-#include <gtk/gtk.h>
-#include <gio/gio.h>
-#include <string.h>
-#include <sys/time.h>
 
 struct CajaSearchDirectoryDetails
 {
@@ -47,7 +49,6 @@ struct CajaSearchDirectoryDetails
     gboolean search_finished;
 
     GList *files;
-    GHashTable *file_hash;
 
     GList *monitor_list;
     GList *callback_list;
@@ -110,8 +111,8 @@ static void
 reset_file_list (CajaSearchDirectory *search)
 {
     GList *list, *monitor_list;
-    CajaFile *file;
     SearchMonitor *monitor;
+    CajaFile *file = NULL;
 
     /* Remove file connections */
     for (list = search->details->files; list != NULL; list = list->next)
@@ -187,7 +188,7 @@ search_monitor_add (CajaDirectory *directory,
     GList *list;
     SearchMonitor *monitor;
     CajaSearchDirectory *search;
-    CajaFile *file;
+    CajaFile *file = NULL;
 
     search = CAJA_SEARCH_DIRECTORY (directory);
 
@@ -218,7 +219,7 @@ static void
 search_monitor_remove_file_monitors (SearchMonitor *monitor, CajaSearchDirectory *search)
 {
     GList *list;
-    CajaFile *file;
+    CajaFile *file = NULL;
 
     for (list = search->details->files; list != NULL; list = list->next)
     {
@@ -241,8 +242,8 @@ search_monitor_remove (CajaDirectory *directory,
                        gconstpointer client)
 {
     CajaSearchDirectory *search;
-    SearchMonitor *monitor;
     GList *list;
+    SearchMonitor *monitor = NULL;
 
     search = CAJA_SEARCH_DIRECTORY (directory);
 
@@ -320,7 +321,7 @@ static void
 search_callback_add_file_callbacks (SearchCallback *callback)
 {
     GList *file_list_copy, *list;
-    CajaFile *file;
+    CajaFile *file = NULL;
 
     file_list_copy = g_list_copy (callback->file_list);
 
@@ -339,8 +340,8 @@ search_callback_add_file_callbacks (SearchCallback *callback)
 static SearchCallback *
 search_callback_find (CajaSearchDirectory *search, CajaDirectoryCallback callback, gpointer callback_data)
 {
-    SearchCallback *search_callback;
     GList *list;
+    SearchCallback *search_callback = NULL;
 
     for (list = search->details->callback_list; list != NULL; list = list->next)
     {
@@ -359,8 +360,8 @@ search_callback_find (CajaSearchDirectory *search, CajaDirectoryCallback callbac
 static SearchCallback *
 search_callback_find_pending (CajaSearchDirectory *search, CajaDirectoryCallback callback, gpointer callback_data)
 {
-    SearchCallback *search_callback;
     GList *list;
+    SearchCallback *search_callback = NULL;
 
     for (list = search->details->pending_callback_list; list != NULL; list = list->next)
     {
@@ -491,7 +492,6 @@ search_cancel_callback (CajaDirectory *directory,
     }
 }
 
-
 static void
 search_engine_hits_added (CajaSearchEngine *engine, GList *hits,
                           CajaSearchDirectory *search)
@@ -499,7 +499,6 @@ search_engine_hits_added (CajaSearchEngine *engine, GList *hits,
     GList *hit_list;
     GList *file_list;
     CajaFile *file;
-    char *uri;
     SearchMonitor *monitor;
     GList *monitor_list;
 
@@ -507,6 +506,8 @@ search_engine_hits_added (CajaSearchEngine *engine, GList *hits,
 
     for (hit_list = hits; hit_list != NULL; hit_list = hit_list->next)
     {
+        char *uri;
+
         uri = hit_list->data;
 
         if (g_str_has_suffix (uri, CAJA_SAVED_SEARCH_EXTENSION))
@@ -547,13 +548,14 @@ search_engine_hits_subtracted (CajaSearchEngine *engine, GList *hits,
     GList *monitor_list;
     SearchMonitor *monitor;
     GList *file_list;
-    char *uri;
     CajaFile *file;
 
     file_list = NULL;
 
     for (hit_list = hits; hit_list != NULL; hit_list = hit_list->next)
     {
+        char *uri;
+
         uri = hit_list->data;
         file = caja_file_get_by_uri (uri);
 
@@ -682,7 +684,6 @@ search_get_file_list (CajaDirectory *directory)
     return caja_file_list_copy (search->details->files);
 }
 
-
 static gboolean
 search_is_editable (CajaDirectory *directory)
 {
@@ -802,7 +803,6 @@ caja_search_directory_generate_new_uri (void)
     return uri;
 }
 
-
 void
 caja_search_directory_set_query (CajaSearchDirectory *search,
                                  CajaQuery *query)
@@ -850,7 +850,6 @@ CajaSearchDirectory *
 caja_search_directory_new_from_saved_search (const char *uri)
 {
     CajaSearchDirectory *search;
-    CajaQuery *query;
     char *file;
 
     search = CAJA_SEARCH_DIRECTORY (g_object_new (CAJA_TYPE_SEARCH_DIRECTORY, NULL));
@@ -860,6 +859,8 @@ caja_search_directory_new_from_saved_search (const char *uri)
     file = g_filename_from_uri (uri, NULL, NULL);
     if (file != NULL)
     {
+        CajaQuery *query;
+
         query = caja_query_load (file);
         if (query != NULL)
         {
@@ -896,7 +897,6 @@ caja_search_directory_is_indexed (CajaSearchDirectory *search)
     return caja_search_engine_is_indexed (search->details->engine);
 }
 
-
 void
 caja_search_directory_save_to_file (CajaSearchDirectory *search,
                                     const char              *save_file_uri)
