@@ -23,29 +23,29 @@
  */
 
 #include <config.h>
-
-#include "caja-connect-server-dialog.h"
-
 #include <string.h>
-#include <eel/eel-stock-dialogs.h>
+
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
+#include <eel/eel-stock-dialogs.h>
+
+#include <libcaja-private/caja-global-preferences.h>
+#include <libcaja-private/caja-icon-names.h>
+
+#include "caja-connect-server-dialog.h"
 #include "caja-application.h"
 #include "caja-bookmark-list.h"
 #include "caja-connect-server-operation.h"
 #include "caja-window.h"
 
-#include <libcaja-private/caja-global-preferences.h>
-#include <libcaja-private/caja-icon-names.h>
-
 /* TODO:
  * - name entry + pre-fill
  * - NetworkManager integration
  */
 
-struct _CajaConnectServerDialogDetails
+struct _CajaConnectServerDialogPrivate
 {
     CajaApplication *application;
 
@@ -79,7 +79,7 @@ struct _CajaConnectServerDialogDetails
     gboolean should_destroy;
 };
 
-G_DEFINE_TYPE (CajaConnectServerDialog, caja_connect_server_dialog,
+G_DEFINE_TYPE_WITH_PRIVATE (CajaConnectServerDialog, caja_connect_server_dialog,
 	       GTK_TYPE_DIALOG)
 
 static void sensitive_entry_changed_callback (GtkEditable *editable,
@@ -92,6 +92,12 @@ enum
     RESPONSE_CONNECT
 };
 
+enum {
+    COL_TYPE_COMBO_INDEX = 0,
+    COL_TYPE_COMBO_DESCRIPTION,
+    COL_TYPE_COMBO_NUM
+};
+
 struct MethodInfo
 {
     const char *scheme;
@@ -176,7 +182,7 @@ connect_dialog_set_connecting (CajaConnectServerDialog *dialog)
 	gint width, height;
 
 	connect_dialog_restore_info_bar (dialog, GTK_MESSAGE_INFO);
-	gtk_widget_show (dialog->details->info_bar);	
+	gtk_widget_show (dialog->details->info_bar);
 
 	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (dialog->details->info_bar));
 
@@ -216,7 +222,7 @@ connect_dialog_gvfs_error (CajaConnectServerDialog *dialog)
 	image = gtk_image_new_from_icon_name ("dialog-error", GTK_ICON_SIZE_SMALL_TOOLBAR);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 6);
 	gtk_widget_show (image);
-	
+
 	label = gtk_label_new (_("Can't load the supported server method list.\n"
 				 "Please check your GVfs installation."));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 6);
@@ -244,7 +250,7 @@ iconized_entry_restore (gpointer data,
 
 	g_signal_handlers_disconnect_by_func (entry,
 					      iconized_entry_changed_cb,
-					      dialog);	
+					      dialog);
 }
 
 static void
@@ -311,7 +317,7 @@ connect_dialog_set_info_bar_error (CajaConnectServerDialog *dialog,
 
 		g_free (str);
 
-		break;		
+		break;
 	case G_IO_ERROR_FAILED:
 	default:
 		label = gtk_label_new (error->message);
@@ -388,14 +394,13 @@ connect_dialog_request_additional_details (CajaConnectServerDialog *self,
 					   const gchar *default_user,
 					   const gchar *default_domain)
 {
-	GtkWidget *content_area, *label, *entry, *hbox, *icon;
+	GtkWidget *content_area, *label, *hbox, *icon;
 
 	self->details->fill_details_flags = flags;
 
 	connect_dialog_restore_info_bar (self, GTK_MESSAGE_WARNING);
 
 	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (self->details->info_bar));
-	entry = NULL;
 
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start (GTK_BOX (content_area), hbox, FALSE, FALSE, 6);
@@ -533,7 +538,7 @@ connect_dialog_connect_to_server (CajaConnectServerDialog *dialog)
     gtk_combo_box_get_active_iter (GTK_COMBO_BOX (dialog->details->type_combo), &iter);
     gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->details->type_combo)),
                         &iter, 0, &index, -1);
-    g_assert (index < G_N_ELEMENTS (methods) && index >= 0);
+    g_assert (index >= 0 && ((gsize) index) < G_N_ELEMENTS (methods));
     meth = &(methods[index]);
 
     server = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->server_entry), 0, -1);
@@ -779,7 +784,7 @@ connect_dialog_setup_for_type (CajaConnectServerDialog *dialog)
 
     gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->details->type_combo)),
                         &iter, 0, &index, -1);
-    g_assert (index < G_N_ELEMENTS (methods) && index >= 0);
+    g_assert (index >= 0 && ((gsize) index) < G_N_ELEMENTS (methods));
     meth = &(methods[index]);
 
     g_object_set (dialog->details->share_entry,
@@ -842,17 +847,15 @@ static void
 caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 {
     GtkWidget *label;
-    GtkWidget *alignment;
     GtkWidget *content_area;
     GtkWidget *combo, *grid;
     GtkWidget *vbox, *hbox, *connect_button, *checkbox;
     GtkListStore *store;
     GtkCellRenderer *renderer;
     gchar *str;
-    int i;
+    gsize i;
 
-    dialog->details = G_TYPE_INSTANCE_GET_PRIVATE (dialog, CAJA_TYPE_CONNECT_SERVER_DIALOG,
-						   CajaConnectServerDialogDetails);
+    dialog->details = caja_connect_server_dialog_get_instance_private (dialog);
 
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
@@ -935,19 +938,21 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
     dialog->details->type_combo = combo = gtk_combo_box_new ();
 
     /* each row contains: method index, textual description */
-    store = gtk_list_store_new (2, G_TYPE_INT, G_TYPE_STRING);
+    store = gtk_list_store_new (COL_TYPE_COMBO_NUM,
+                                G_TYPE_INT,      /* COL_TYPE_COMBO_INDEX */
+                                G_TYPE_STRING);  /* COL_TYPE_COMBO_DESCRIPTION */
     gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
     g_object_unref (store);
 
     renderer = gtk_cell_renderer_text_new ();
     gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
-    gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo), renderer, "text", 1);
+    gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo), renderer, "text",
+                                   COL_TYPE_COMBO_DESCRIPTION);
 
     for (i = 0; i < G_N_ELEMENTS (methods); i++)
     {
         GtkTreeIter iter;
         const gchar * const *supported;
-        int j;
 
 		/* skip methods that don't have corresponding gvfs uri schemes */
         supported = g_vfs_get_supported_uri_schemes (g_vfs_get_default ());
@@ -955,6 +960,7 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
         if (methods[i].scheme != NULL)
         {
             gboolean found;
+            int j;
 
             found = FALSE;
             for (j = 0; supported[j] != NULL; j++)
@@ -974,11 +980,10 @@ caja_connect_server_dialog_init (CajaConnectServerDialog *dialog)
 
         gtk_list_store_append (store, &iter);
         gtk_list_store_set (store, &iter,
-                            0, i,
-                            1, get_method_description (&(methods[i])),
+                            COL_TYPE_COMBO_INDEX, (int) i,
+                            COL_TYPE_COMBO_DESCRIPTION, get_method_description (&(methods[i])),
                             -1);
 
-
         if (methods[i].flags & DEFAULT_METHOD)
         {
             gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
@@ -1167,8 +1172,6 @@ caja_connect_server_dialog_class_init (CajaConnectServerDialogClass *class)
 
 	oclass = G_OBJECT_CLASS (class);
 	oclass->finalize = caja_connect_server_dialog_finalize;
-
-	g_type_class_add_private (class, sizeof (CajaConnectServerDialogDetails));
 }
 
 GtkWidget *
@@ -1228,6 +1231,12 @@ caja_connect_server_dialog_fill_details_async (CajaConnectServerDialog *self,
 							str);
 			set_flags ^= G_ASK_PASSWORD_NEED_PASSWORD;
 
+			if (flags & G_ASK_PASSWORD_SAVING_SUPPORTED &&
+			    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->details->remember_checkbox))) {
+				g_mount_operation_set_password_save (G_MOUNT_OPERATION (operation),
+								     G_PASSWORD_SAVE_PERMANENTLY);
+			}
+
 			self->details->last_password_set = TRUE;
 		}
 	}
