@@ -91,7 +91,6 @@ static void mouse_forward_button_changed	     (gpointer                  callbac
 static void use_extra_mouse_buttons_changed          (gpointer                  callback_data);
 static CajaWindowSlot *create_extra_pane         (CajaNavigationWindow *window);
 
-
 G_DEFINE_TYPE_WITH_PRIVATE (CajaNavigationWindow, caja_navigation_window, CAJA_TYPE_WINDOW)
 #define parent_class caja_navigation_window_parent_class
 
@@ -520,7 +519,7 @@ caja_navigation_window_key_press_event (GtkWidget *widget,
                                         GdkEventKey *event)
 {
     CajaNavigationWindow *window;
-    int i;
+    gsize i;
 
     window = CAJA_NAVIGATION_WINDOW (widget);
 
@@ -605,12 +604,12 @@ caja_navigation_window_button_press_event (GtkWidget *widget,
     handled = FALSE;
     window = CAJA_NAVIGATION_WINDOW (widget);
 
-    if (mouse_extra_buttons && (event->button == mouse_back_button))
+    if (mouse_extra_buttons && (((int) event->button) == mouse_back_button))
     {
         caja_navigation_window_go_back (window);
         handled = TRUE;
     }
-    else if (mouse_extra_buttons && (event->button == mouse_forward_button))
+    else if (mouse_extra_buttons && (((int) event->button) == mouse_forward_button))
     {
         caja_navigation_window_go_forward (window);
         handled = TRUE;
@@ -1018,7 +1017,6 @@ caja_navigation_window_status_bar_showing (CajaNavigationWindow *window)
     return TRUE;
 }
 
-
 void
 caja_navigation_window_hide_toolbar (CajaNavigationWindow *window)
 {
@@ -1084,7 +1082,7 @@ gint
 caja_navigation_window_get_base_page_index (CajaNavigationWindow *window)
 {
     CajaNavigationWindowSlot *slot;
-    gint forward_count;
+    guint forward_count;
 
     slot = CAJA_NAVIGATION_WINDOW_SLOT (CAJA_WINDOW (window)->details->active_pane->active_slot);
 
@@ -1099,7 +1097,7 @@ caja_navigation_window_get_base_page_index (CajaNavigationWindow *window)
     /* The forward count indicate the relative postion of the base page
      * in the history list
      */
-    return forward_count;
+    return (int) forward_count;
 }
 
 /**
