@@ -27,7 +27,6 @@
 typedef struct _CajaPathBar      CajaPathBar;
 typedef struct _CajaPathBarClass CajaPathBarClass;
 
-
 #define CAJA_TYPE_PATH_BAR                 (caja_path_bar_get_type ())
 #define CAJA_PATH_BAR(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), CAJA_TYPE_PATH_BAR, CajaPathBar))
 #define CAJA_PATH_BAR_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), CAJA_TYPE_PATH_BAR, CajaPathBarClass))
@@ -71,15 +70,19 @@ struct _CajaPathBarClass
 
     void (* path_clicked)   (CajaPathBar  *path_bar,
                              GFile             *location);
-    void (* path_set)       (CajaPathBar  *path_bar,
-                             GFile             *location);
+
+    void (* path_event)     (CajaPathBar  *path_bar,
+                             GdkEventButton   *event,
+                             GFile            *location);
 };
 
 GType    caja_path_bar_get_type (void) G_GNUC_CONST;
 
 gboolean caja_path_bar_set_path    (CajaPathBar *path_bar, GFile *file);
+
 GFile *  caja_path_bar_get_path_for_button (CajaPathBar *path_bar,
         GtkWidget       *button);
+
 void     caja_path_bar_clear_buttons (CajaPathBar *path_bar);
 
 GtkWidget * caja_path_bar_get_button_from_button_list_entry (gpointer entry);
