@@ -22,16 +22,17 @@
  *
  */
 
-#include "config.h"
+#include <config.h>
+#include <string.h>
 
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include <string.h>
 
-#include "caja-x-content-bar.h"
 #include <libcaja-private/caja-autorun.h>
 #include <libcaja-private/caja-icon-info.h>
 
+#include "caja-x-content-bar.h"
+
 struct _CajaXContentBarPrivate
 {
     GtkWidget *label;
@@ -109,7 +110,6 @@ caja_x_content_bar_set_x_content_type (CajaXContentBar *bar, const char *x_conte
         message = g_strdup_printf (_("The media has been detected as \"%s\"."), description);
     }
 
-
     gtk_label_set_text (GTK_LABEL (bar->priv->label), message);
     gtk_widget_show (bar->priv->label);
 
@@ -183,7 +183,6 @@ caja_x_content_bar_set_mount (CajaXContentBar *bar, GMount *mount)
     bar->priv->mount = mount != NULL ? g_object_ref (mount) : NULL;
 }
 
-
 static void
 caja_x_content_bar_set_property (GObject      *object,
                                  guint         prop_id,
