@@ -25,16 +25,21 @@
 */
 
 #include <config.h>
-#include "fm-list-model.h"
-#include <libegg/eggtreemultidnd.h>
-
+#include <glib.h>
 #include <string.h>
-#include <eel/eel-graphic-effects.h>
+#include <cairo-gobject.h>
+
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+
+#include <libegg/eggtreemultidnd.h>
+
+#include <eel/eel-graphic-effects.h>
+
 #include <libcaja-private/caja-dnd.h>
-#include <glib.h>
-#include <cairo-gobject.h>
+#include <libcaja-private/caja-global-preferences.h>
+
+#include "fm-list-model.h"
 
 enum
 {
@@ -47,9 +52,6 @@ static GQuark attribute_name_q,
        attribute_modification_date_q,
        attribute_date_modified_q;
 
-/* msec delay after Loading... dummy row turns into (empty) */
-#define LOADING_TO_EMPTY_DELAY 100
-
 static guint list_model_signals[LAST_SIGNAL] = { 0 };
 
 static int fm_list_model_file_entry_compare_func (gconstpointer a,
@@ -198,7 +200,7 @@ fm_list_model_get_iter (GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreePath
     GSequence *files;
     GSequenceIter *ptr;
     FileEntry *file_entry;
-    int i, d;
+    int d;
 
     model = (FMListModel *)tree_model;
     ptr = NULL;
@@ -206,6 +208,8 @@ fm_list_model_get_iter (GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreePath
     files = model->details->files;
     for (d = 0; d < gtk_tree_path_get_depth (path); d++)
     {
+        int i;
+
         i = gtk_tree_path_get_indices (path)[d];
 
         if (files == NULL || i >= g_sequence_get_length (files))
@@ -231,7 +235,6 @@ fm_list_model_get_path (GtkTreeModel *tree_model, GtkTreeIter *iter)
     GSequenceIter *ptr;
     FileEntry *file_entry;
 
-
     model = (FMListModel *)tree_model;
 
     g_return_val_if_fail (iter->stamp == model->details->stamp, NULL);
@@ -282,19 +285,11 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
     FMListModel *model;
     FileEntry *file_entry;
     CajaFile *file;
-    char *str;
-    GdkPixbuf *icon, *rendered_icon;
-    GIcon *gicon, *emblemed_icon, *emblem_icon;
-    CajaIconInfo *icon_info;
-    GEmblem *emblem;
+    GdkPixbuf *rendered_icon;
+    GIcon *emblemed_icon;
     GList *emblem_icons, *l;
-    int icon_size, icon_scale;
     CajaZoomLevel zoom_level;
-    CajaFile *parent_file;
-    char *emblems_to_ignore[3];
-    int i;
     CajaFileIconFlags flags;
-    cairo_surface_t *surface;
 
     model = (FMListModel *)tree_model;
 
@@ -323,10 +318,34 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
     case FM_LIST_MODEL_LARGE_ICON_COLUMN:
     case FM_LIST_MODEL_LARGER_ICON_COLUMN:
     case FM_LIST_MODEL_LARGEST_ICON_COLUMN:
+        if (!g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_SHOW_ICONS_IN_LIST_VIEW)) {
+            cairo_surface_t *surface;
+            int icon_size;
+
+            g_value_init (value, CAIRO_GOBJECT_TYPE_SURFACE);
+
+            zoom_level = fm_list_model_get_zoom_level_from_column_id (column);
+            icon_size = caja_get_icon_size_for_zoom_level (zoom_level);
+
+            surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, icon_size, icon_size);
+            g_value_take_boxed (value, surface);
+            break;
+        }
         g_value_init (value, CAIRO_GOBJECT_TYPE_SURFACE);
 
         if (file != NULL)
         {
+            GdkPixbuf *icon;
+            GIcon *gicon;
+            CajaIconInfo *icon_info;
+            GEmblem *emblem;
+            int icon_size, icon_scale;
+            CajaFile *parent_file;
+            char *emblems_to_ignore[3];
+            int i;
+            cairo_surface_t *surface;
+            const char *icon_name;
+
             zoom_level = fm_list_model_get_zoom_level_from_column_id (column);
             icon_size = caja_get_icon_size_for_zoom_level (zoom_level);
             icon_scale = fm_list_model_get_icon_scale (model);
@@ -336,13 +355,15 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
                     CAJA_FILE_ICON_FLAGS_USE_MOUNT_ICON_AS_EMBLEM;
             if (model->details->drag_view != NULL)
             {
-                GtkTreePath *path_a, *path_b;
+                GtkTreePath *path_a;
 
                 gtk_tree_view_get_drag_dest_row (model->details->drag_view,
                                                  &path_a,
                                                  NULL);
                 if (path_a != NULL)
                 {
+                    GtkTreePath *path_b;
+
                     path_b = gtk_tree_model_get_path (tree_model, iter);
 
                     if (gtk_tree_path_compare (path_a, path_b) == 0)
@@ -374,6 +395,8 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
             					       emblems_to_ignore);
 
             if (emblem_icons != NULL) {
+                GIcon *emblem_icon;
+
                 emblem_icon = emblem_icons->data;
                 emblem = g_emblem_new (emblem_icon);
                 emblemed_icon = g_emblemed_icon_new (gicon, emblem);
@@ -395,7 +418,13 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
             	gicon = emblemed_icon;
             }
 
-            icon_info = caja_icon_info_lookup (gicon, icon_size, icon_scale);
+            icon_info = caja_file_get_icon (file, icon_size, icon_scale, flags);
+            icon_name = caja_icon_info_get_used_name (icon_info);
+
+            if (icon_name != NULL) {
+                g_object_unref (icon_info);
+                icon_info = caja_icon_info_lookup (gicon, icon_size, icon_scale);
+            }
             icon = caja_icon_info_get_pixbuf_at_size (icon_info, icon_size);
 
             g_object_unref (icon_info);
@@ -437,6 +466,8 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
                           NULL);
             if (file != NULL)
             {
+                char *str;
+
                 str = caja_file_get_string_attribute_with_default_q (file,
                         attribute);
                 g_value_take_string (value, str);
@@ -599,7 +630,6 @@ static GSequenceIter *
 lookup_file (FMListModel *model, CajaFile *file,
              CajaDirectory *directory)
 {
-    FileEntry *file_entry;
     GSequenceIter *ptr, *parent_ptr;
 
     parent_ptr = NULL;
@@ -611,6 +641,8 @@ lookup_file (FMListModel *model, CajaFile *file,
 
     if (parent_ptr)
     {
+        FileEntry *file_entry;
+
         file_entry = g_sequence_get (parent_ptr);
         ptr = g_hash_table_lookup (file_entry->reverse_map, file);
     }
@@ -627,7 +659,6 @@ lookup_file (FMListModel *model, CajaFile *file,
     return ptr;
 }
 
-
 struct GetIters
 {
     FMListModel *model;
@@ -701,7 +732,6 @@ fm_list_model_get_first_iter_for_file (FMListModel          *model,
     return res;
 }
 
-
 gboolean
 fm_list_model_get_tree_iter_from_file (FMListModel *model, CajaFile *file,
                                        CajaDirectory *directory,
@@ -777,8 +807,8 @@ fm_list_model_sort_file_entries (FMListModel *model, GSequence *files, GtkTreePa
     int *new_order;
     int length;
     int i;
-    FileEntry *file_entry;
     gboolean has_iter;
+    FileEntry *file_entry = NULL;
 
     length = g_sequence_get_length (files);
 
@@ -794,6 +824,7 @@ fm_list_model_sort_file_entries (FMListModel *model, GSequence *files, GtkTreePa
         GSequenceIter *ptr = g_sequence_get_iter_at_pos (files, i);
 
         file_entry = g_sequence_get (ptr);
+
         if (file_entry->files != NULL)
         {
             gtk_tree_path_append_index (path, i);
@@ -912,12 +943,12 @@ each_path_get_data_binder (CajaDragEachSelectedItemDataGet data_get,
 {
     DragDataGetInfo *info;
     GList *l;
-    CajaFile *file;
-    GtkTreeRowReference *row;
-    GtkTreePath *path;
     char *uri;
     GdkRectangle cell_area;
     GtkTreeViewColumn *column;
+    CajaFile *file = NULL;
+    GtkTreeRowReference *row = NULL;
+    GtkTreePath *path = NULL;
 
     info = context;
 
@@ -931,6 +962,7 @@ each_path_get_data_binder (CajaDragEachSelectedItemDataGet data_get,
 
         path = gtk_tree_row_reference_get_path (row);
         file = fm_list_model_file_for_path (info->model, path);
+
         if (file)
         {
             gtk_tree_view_get_cell_area
@@ -1086,7 +1118,6 @@ fm_list_model_add_file (FMListModel *model, CajaFile *file,
         }
     }
 
-
     file_entry->ptr = g_sequence_insert_sorted (files, file_entry,
                       fm_list_model_file_entry_compare_func, model);
 
@@ -1125,12 +1156,10 @@ fm_list_model_file_changed (FMListModel *model, CajaFile *file,
 {
     FileEntry *parent_file_entry;
     GtkTreeIter iter;
-    GtkTreePath *path, *parent_path;
+    GtkTreePath *path;
     GSequenceIter *ptr;
-    int pos_before, pos_after, length, i, old;
-    int *new_order;
+    int pos_before, pos_after;
     gboolean has_iter;
-    GSequence *files;
 
     ptr = lookup_file (model, file, directory);
     if (!ptr)
@@ -1138,7 +1167,6 @@ fm_list_model_file_changed (FMListModel *model, CajaFile *file,
         return;
     }
 
-
     pos_before = g_sequence_iter_get_position (ptr);
 
     g_sequence_sort_changed (ptr, fm_list_model_file_entry_compare_func, model);
@@ -1147,6 +1175,11 @@ fm_list_model_file_changed (FMListModel *model, CajaFile *file,
 
     if (pos_before != pos_after)
     {
+        GtkTreePath *parent_path;
+        int length, i, old;
+        int *new_order;
+        GSequence *files;
+
         /* The file moved, we need to send rows_reordered */
 
         parent_file_entry = ((FileEntry *)g_sequence_get (ptr))->parent;
@@ -1210,8 +1243,8 @@ fm_list_model_get_length (FMListModel *model)
 static void
 fm_list_model_remove (FMListModel *model, GtkTreeIter *iter)
 {
-    GSequenceIter *ptr, *child_ptr;
-    FileEntry *file_entry, *child_file_entry, *parent_file_entry;
+    GSequenceIter *ptr;
+    FileEntry *file_entry, *parent_file_entry;
     GtkTreePath *path;
     GtkTreeIter parent_iter;
 
@@ -1220,10 +1253,14 @@ fm_list_model_remove (FMListModel *model, GtkTreeIter *iter)
 
     if (file_entry->files != NULL)
     {
+        GSequenceIter *child_ptr = NULL;
+        FileEntry *child_file_entry = NULL;
+
         while (g_sequence_get_length (file_entry->files) > 0)
         {
             child_ptr = g_sequence_get_begin_iter (file_entry->files);
             child_file_entry = g_sequence_get (child_ptr);
+
             if (child_file_entry->file != NULL)
             {
                 fm_list_model_remove_file (model,
@@ -1313,13 +1350,14 @@ static void
 fm_list_model_clear_directory (FMListModel *model, GSequence *files)
 {
     GtkTreeIter iter;
-    FileEntry *file_entry;
+    FileEntry *file_entry = NULL;
 
     while (g_sequence_get_length (files) > 0)
     {
         iter.user_data = g_sequence_get_begin_iter (files);
 
         file_entry = g_sequence_get (iter.user_data);
+
         if (file_entry->files != NULL)
         {
             fm_list_model_clear_directory (model, file_entry->files);
@@ -1401,8 +1439,7 @@ fm_list_model_load_subdirectory (FMListModel *model, GtkTreePath *path, CajaDire
 void
 fm_list_model_unload_subdirectory (FMListModel *model, GtkTreeIter *iter)
 {
-    GSequenceIter *child_ptr;
-    FileEntry *file_entry, *child_file_entry;
+    FileEntry *file_entry;
     GtkTreeIter child_iter;
 
     file_entry = g_sequence_get (iter->user_data);
@@ -1417,8 +1454,12 @@ fm_list_model_unload_subdirectory (FMListModel *model, GtkTreeIter *iter)
     /* Remove all children */
     while (g_sequence_get_length (file_entry->files) > 0)
     {
+        GSequenceIter *child_ptr;
+        FileEntry *child_file_entry;
+
         child_ptr = g_sequence_get_begin_iter (file_entry->files);
         child_file_entry = g_sequence_get (child_ptr);
+
         if (child_file_entry->file == NULL)
         {
             /* Don't delete the dummy node */
@@ -1447,8 +1488,6 @@ fm_list_model_unload_subdirectory (FMListModel *model, GtkTreeIter *iter)
     file_entry->reverse_map = NULL;
 }
 
-
-
 void
 fm_list_model_set_should_sort_directories_first (FMListModel *model, gboolean sort_directories_first)
 {
@@ -1609,12 +1648,13 @@ static void
 fm_list_model_dispose (GObject *object)
 {
     FMListModel *model;
-    int i;
 
     model = FM_LIST_MODEL (object);
 
     if (model->details->columns)
     {
+        int i;
+
         for (i = 0; i < model->details->columns->len; i++)
         {
             g_object_unref (model->details->columns->pdata[i]);
@@ -1742,8 +1782,7 @@ void
 fm_list_model_subdirectory_done_loading (FMListModel *model, CajaDirectory *directory)
 {
     GtkTreeIter iter;
-    GtkTreePath *path;
-    FileEntry *file_entry, *dummy_entry;
+    FileEntry *file_entry;
     GSequenceIter *parent_ptr, *dummy_ptr;
     GSequence *files;
 
@@ -1767,10 +1806,14 @@ fm_list_model_subdirectory_done_loading (FMListModel *model, CajaDirectory *dire
     if (!caja_directory_is_not_empty (directory) &&
             g_sequence_get_length (files) == 1)
     {
+        FileEntry *dummy_entry;
+
         dummy_ptr = g_sequence_get_iter_at_pos (file_entry->files, 0);
         dummy_entry = g_sequence_get (dummy_ptr);
         if (dummy_entry->file == NULL)
         {
+            GtkTreePath *path;
+
             /* was the dummy file */
             file_entry->loaded = 1;
 
@@ -1791,7 +1834,7 @@ refresh_row (gpointer data,
     CajaFile *file;
     FMListModel *model;
     GList *iters, *l;
-    GtkTreePath *path;
+    GtkTreePath *path = NULL;
 
     model = user_data;
     file = data;
